@@ -32,7 +32,6 @@ def physnoob() -> None:
 def _recover(status: int, in_terminal: bool) -> None:
     from phystool.helper import terminal_yes_no
     from phystool.physgit import is_valid_git_remote, clone_git_repository
-    from phystool.physql.metadata import consolidate
 
     match status:
         case config.Status.MISSING_DB:
@@ -49,9 +48,6 @@ def _recover(status: int, in_terminal: bool) -> None:
             logger.error("The configuration file is not valid")
         case config.Status.MISSING_PDB_TYPE:
             logger.error("The configuration file doesn't define valid PDBType")
-        case config.Status.MISSING_SQL_FILE:
-            logger.error("No SQL file found")
-            consolidate()
 
     if config.setup_db() != config.Status.READY:
         raise RuntimeError("The initialisation and automatic recovery attempt failed")
