@@ -1,6 +1,7 @@
 from argparse import ArgumentParser, ArgumentDefaultsHelpFormatter
 from logging import getLogger
 from pathlib import Path
+from sys import exit
 from uuid import UUID
 
 from phystool.config import config
@@ -51,34 +52,34 @@ def _search(args) -> None:
 def _pdbfile(args) -> None:
     from phystool.pdbfile import PDBFile
 
-    if args.compile:
+    try:
         pdb_file = PDBFile.from_file(args.uuid)
+    except ValueError as e:
+        logger.error(e)
+        exit(1)
+
+    if args.compile:
         pdb_file.compile(True)
-    elif args.pytex:
-        from phystool.pytex import PyTex
-
-        PyTex(args.uuid)
-    elif args.cat:
-        from phystool.helper import bat
-
-        bat(args.uuid)
     elif args.zip:
-        try:
-            pdb_file = PDBFile.from_file(args.uuid)
-            pdb_file.zip()
-        except FileNotFoundError:
-            logger.error(f"PDBFile '{args.uuid}' does not exist")
+        pdb_file.zip()
+    elif args.cat:
+        pdb_file.bat()
     elif args.update:
         from phystool.physql.metadata import update_pdb_file
 
-        update_pdb_file(args.uuid)
+        update_pdb_file(pdb_file)
+        print(pdb_file)
     elif args.remove:
-        from phystool.helper import terminal_yes_no, bat
+        from phystool.helper import terminal_yes_no
         from phystool.physql.metadata import remove_pdb_files
 
-        bat(args.uuid)
+        pdb_file.bat()
         if terminal_yes_no("Remove files?"):
-            remove_pdb_files([args.uuid])
+            remove_pdb_files([pdb_file.uuid])
+    elif args.pytex:
+        from phystool.pytex import PyTex
+
+        PyTex(pdb_file.uuid)
 
 
 def _tags(args) -> None:
@@ -109,39 +110,77 @@ def _pdflatex(args) -> None:
 
     if not args.filename.exists():
         logger.error(f"'{args.filename}' not found")
+        exit(1)
     elif args.filename.suffix == ".log" or args.logtex:
         if not args.filename.with_suffix(".log").exists():
             args.filename = texfile_to_symlink(args.filename).with_suffix(".log")
             if not args.filename.exists():
                 logger.error(f"'{args.filename}' not found")
-                return
+                exit(1)
         llp = LatexLogParser(args.filename)
         llp.process()
         llp.as_log()
     else:
         pdflatex = PdfLatex(texfile_to_symlink(args.filename))
         if args.output:
-            pdflatex.full_compile(args.output, args.can_recompile)
+            if not pdflatex.full_compile(args.output, args.can_recompile):
+                exit(1)
         if args.clean:
             pdflatex.clean([".aux", ".log", ".out", ".toc"])
 
 
-def _evaluation(args):
-    from phystool.evaluation import EvaluationManager
+def _evaluation_action(args):
+    from phystool.evaluation import Evaluation, load_klass_and_evaluation_data
 
-    metadata = EvaluationManager()
-    if args.klass_list_current:
-        metadata.klass_list()
-    elif args.create_for_klass:
-        metadata.evaluation_create_for_klass(args.create_for_klass)
-    elif args.list_current:
-        metadata.evaluation_list()
-    elif args.search:
-        metadata.evaluation_search(args.search)
-    elif args.edit:
-        metadata.evaluation_edit(args.edit)
-    elif args.update:
-        metadata.evaluation_update(args.update)
+    load_klass_and_evaluation_data()
+    evaluation_uuids = Evaluation.search(
+        year=args.year,
+        exuuid=args.exuuid,
+        evuuid=args.evuuid,
+        cluuid=args.cluuid,
+    )
+    match args.action:
+        case "display":
+            for uuid in evaluation_uuids:
+                Evaluation.display(uuid)
+        case "list":
+            for uuid in evaluation_uuids:
+                print(uuid, Evaluation.all[uuid])
+        case "update":
+            if not Evaluation.update(args.evuuid, args.fname):
+                exit(1)
+        case "create":
+            if not Evaluation.create(args.fname):
+                exit(1)
+
+
+def _klass_action(args):
+    from phystool.evaluation import Klass, load_klass_and_evaluation_data
+
+    load_klass_and_evaluation_data()
+    klass_uuids = Klass.search(name=args.name, year=args.year)
+    match args.action:
+        case "display":
+            for uuid in klass_uuids:
+                Klass.display(uuid)
+        case "list":
+            for uuid in klass_uuids:
+                print(uuid, Klass.all[uuid])
+        case "update":
+            if not Klass.update(
+                uuid=args.cluuid,
+                name=args.name,
+                extra=args.extra,
+                year=args.year,
+            ):
+                exit(1)
+        case "create":
+            if not Klass.create(
+                name=args.name,
+                extra=args.extra,
+                year=args.year,
+            ):
+                exit(1)
 
 
 def get_parser():
@@ -271,16 +310,15 @@ def get_parser():
         formatter_class=ArgumentDefaultsHelpFormatter,
     )
     tags_subparser.set_defaults(func=_tags)
-    # TODO: fix doc
     tags_subparser.add_argument(
         "--add",
-        help="Add tags given as a comma separated list",
+        help="Add tags given as a comma separated list of ids",
         type=lambda x: {int(i.strip()) for i in x.split(",")},
         default=set(),
     )
     tags_subparser.add_argument(
         "--remove",
-        help="Remove tags given as a comma separated list",
+        help="Remove tags given as a comma separated list of ids",
         type=lambda x: {int(i.strip()) for i in x.split(",")},
         default=set(),
     )
@@ -329,41 +367,81 @@ def get_parser():
         help="Remove auxiliary files",
         action="store_true",
     )
+    if config.EVALUATION_PATH.exists():
+        ###########################
+        # evaluation
+        ###########################
+        evaluation_subparser = sub_parser.add_parser(
+            "evaluation",
+            help="Manage evaluations",
+            formatter_class=ArgumentDefaultsHelpFormatter,
+        )
+        evaluation_subparser.set_defaults(func=_evaluation_action)
+        evaluation_subparser.add_argument(
+            "action",
+            help="Acts uppon evaluations",
+            choices=["display", "list", "update", "create"],
+        )
+        evaluation_subparser.add_argument(
+            "--evuuid",
+            help="Evaluation UUID",
+            type=UUID,
+        )
+        evaluation_subparser.add_argument(
+            "--exuuid",
+            help="Exercise UUID",
+            type=UUID,
+        )
+        evaluation_subparser.add_argument(
+            "--cluuid",
+            help="Class UUID",
+            type=UUID,
+        )
+        evaluation_subparser.add_argument(
+            "--year",
+            help="Scolar year",
+            default=0,
+            type=int,
+        )
+        evaluation_subparser.add_argument(
+            "--fname",
+            help="Evaluation file to process",
+            type=Path,
+        )
 
-    ###########################
-    # evaluation
-    ###########################
-    evaluation_parser = sub_parser.add_parser(
-        "evaluation",
-        help="Manage evaluations",
-        formatter_class=ArgumentDefaultsHelpFormatter,
-    )
-    evaluation_parser.set_defaults(func=_evaluation)
-    evaluation_parser.add_argument(
-        "--klass-list-current",
-        help="List classes of the current year",
-        action="store_true",
-    )
-    evaluation_parser.add_argument(
-        "--list-current",
-        help="List current evaluations",
-        action="store_true",
-    )
-    evaluation_parser.add_argument(
-        "--create-for-klass",
-        help="Create new evaluation klass",
-    )
-    evaluation_parser.add_argument(
-        "--edit",
-        help="Edit evaluation in extracted json file",
-    )
-    evaluation_parser.add_argument(
-        "--update",
-        help="Update evaluation",
-    )
-    evaluation_parser.add_argument(
-        "--search",
-        help="Search evaluations using given PDBFile",
-    )
+        ###########################
+        # Klass
+        ###########################
+        klass_subparser = sub_parser.add_parser(
+            "class",
+            help="Manage classes",
+            formatter_class=ArgumentDefaultsHelpFormatter,
+        )
+        klass_subparser.set_defaults(func=_klass_action)
+        klass_subparser.add_argument(
+            "action",
+            help="Acts uppon classes",
+            choices=["display", "list", "update", "create"],
+        )
+        klass_subparser.add_argument(
+            "--cluuid",
+            help="Class UUID",
+            type=UUID,
+        )
+        klass_subparser.add_argument(
+            "--name",
+            help="Class name",
+        )
+        klass_subparser.add_argument(
+            "--year",
+            help="Scolar year",
+            default=0,
+            type=int,
+        )
+        klass_subparser.add_argument(
+            "--extra",
+            help="Extra info",
+            choices=["OS", "DF"],
+        )
 
     return parser
