@@ -1,5 +1,4 @@
 import subprocess
-import json
 
 from collections import deque
 from logging import getLogger
@@ -92,29 +91,6 @@ def greptex(query: str, path: Path, silent: bool) -> set[UUID]:
         return set()
 
 
-def bat(uuid: UUID) -> None:
-    """Display file in terminal with bat.
-
-    The extension is detected from the filename extension
-
-    :param path: file to display
-    :param title: title displayed in the bat header
-    """
-    path = config.db.DB_DIR / str(uuid)
-    with path.with_suffix(".json").open() as jsin:
-        pdb_data = json.load(jsin)
-    subprocess.run(
-        [
-            "bat",
-            "--language",
-            "tex",
-            "--file-name",
-            pdb_data["title"],
-            path.with_suffix(".tex"),
-        ]
-    )
-
-
 def as_valid_filename(value: str) -> str:
     """
     Taken from slugify at https://github.com/django/django/blob/stable/5.2.x/
