@@ -322,10 +322,10 @@ class LogMessageList[T: LogFileMessage]:
 class LatexLogParser:
     """
     LatexLogParser parses a LaTeX log file to generate lists of errors,
-    warnings, bad boxes and infos. Each message is stored as a LogFileMessage
+    warnings, infos and bad boxes. Each message is stored as a LogFileMessage
     in the corresponding list.
 
-    Relies on the fact that 'texmf.cnf' has been configured so that filenames
+    To properly parse the log file, 'texmf.cnf' must be configured so that filenames
     are written on single line ('max_print_line=1000')
 
     :param texfile: LaTeX file for which the log should be parsed
@@ -449,21 +449,10 @@ class PdfLatex:
             return fname
         raise ValueError
 
-    @classmethod
-    def compilation_command(cls, fullname: Path) -> list[str]:
-        return [
-            "pdflatex",
-            "-shell-escape",
-            "-interaction=nonstopmode",
-            "-halt-on-error",
-            f"-output-directory={fullname.parent}",
-            str(fullname),
-        ]
-
     def __init__(self, fullname: Path):
         self._fullname = fullname.with_suffix(".tex")
 
-    def full_compile(self, dest: Path | None, can_recompile: bool) -> None:
+    def full_compile(self, dest: Path | None, can_recompile: bool) -> bool:
         try:
             self.compile()
 
@@ -479,17 +468,19 @@ class PdfLatex:
                 logger.info("Automatic recompilation successful")
 
             self.move_pdf(dest)
+            return True
         except self.CompilationError:
             llp = LatexLogParser(self._fullname, [Latex3Message, ErrorMessage])
             llp.process()
             llp.as_log()
         except self.MoveError:
             logger.error(f"Moving pdf to {dest} failed")
+        return False
 
     def compile(self, env: dict[str, str] | None = None) -> None:
         try:
             subprocess.run(
-                self.compilation_command(self._fullname),
+                self.compilation_command(),
                 capture_output=True,
                 check=True,
                 env=env,
@@ -499,6 +490,16 @@ class PdfLatex:
             logger.error(f"{self._fullname.name}: pdflatex failed")
             raise self.CompilationError
 
+    def compilation_command(self) -> list[str]:
+        return [
+            "pdflatex",
+            "-shell-escape",
+            "-interaction=nonstopmode",
+            "-halt-on-error",
+            f"-output-directory={self._fullname.parent}",
+            str(self._fullname),
+        ]
+
     def convert_pdf_to_png(
         self, dest_files: list[Path] = [], cropped: bool = False
     ) -> None:
