@@ -91,11 +91,19 @@ class MainWindow(QMainWindow):
 
         menu_database = main_menu.addMenu("Changer de DB")
         for db_name in config.get_db_list():
-            self._add_action_menu(db_name, None, pdb_file_widget.load_db, menu_database)
+            self._add_action_menu(
+                db_name,
+                None,
+                pdb_file_widget.load_db,
+                menu_database,
+            )
 
         main_menu.addSeparator()
         self._add_action_menu(
-            "&Quitter", QKeySequence.StandardKey.Quit, self._quit, main_menu
+            "&Quitter",
+            QKeySequence.StandardKey.Quit,
+            self._quit,
+            main_menu,
         )
 
         file_menu = menu.addMenu("&File")
@@ -139,10 +147,16 @@ class MainWindow(QMainWindow):
 
         meta_menu = menu.addMenu("&Metadata")
         self._add_action_menu(
-            "Créer un nouveau &tag", None, filter_widget.create_new_tag, meta_menu
+            "Créer un nouveau &tag",
+            None,
+            filter_widget.create_new_tag,
+            meta_menu,
         )
         self._add_action_menu(
-            "Consolider la &DB", None, pdb_file_widget.consolidate, meta_menu
+            "Consolider la &DB",
+            None,
+            pdb_file_widget.consolidate,
+            meta_menu,
         )
         self._add_action_menu(
             "&Stage and commit",
