@@ -1,12 +1,7 @@
 from logging import getLogger
 from typing import cast
 
-from PySide6.QtCore import (
-    QSettings,
-    Qt,
-    Signal,
-    Slot,
-)
+from PySide6.QtCore import QSettings, Qt, Signal, Slot
 from PySide6.QtWidgets import (
     QCheckBox,
     QComboBox,
@@ -23,7 +18,7 @@ from PySide6.QtWidgets import (
 
 from phystool.config import config
 from phystool.pdbfile import PDBFile
-from phystool.physql.metadata import filter_pdb_files
+from phystool.physql.metadata import create_new_tag, filter_pdb_files
 from phystool.tags import Tags
 
 
@@ -54,7 +49,7 @@ class FilterWidget(QWidget):
         self._uuid_bit = ""
         self._excluded_tags: Tags
         self._selected_tags: Tags
-        self._selected_types: list[str]
+        self._selected_types: set[str]
 
         self._filters_layout = QHBoxLayout()
         self._pdb_types_layout = QHBoxLayout()
@@ -76,7 +71,7 @@ class FilterWidget(QWidget):
             if tmp := child.widget():
                 tmp.deleteLater()
 
-        for pdb_type in config.db.VALID_PDB_TYPES:
+        for pdb_type in config.db.PDB_TYPES.keys():
             button = PDBTypeCheckBox(pdb_type, self, pdb_type in self._selected_types)
             button.toggled.connect(self._filter_pdb_type)
             self._pdb_types_layout.addWidget(button)
@@ -90,7 +85,7 @@ class FilterWidget(QWidget):
             if tmp := child.widget():
                 tmp.deleteLater()
 
-        for category, tags in Tags.TAGS():
+        for category, tags in Tags.manager.tags:
             layout = QVBoxLayout()
             label = QLabel(category.capitalize())
             label.setAlignment(Qt.AlignmentFlag.AlignTop | Qt.AlignmentFlag.AlignLeft)
@@ -100,9 +95,9 @@ class FilterWidget(QWidget):
             for tag_name in tags:
                 button = TagCheckBox(category, tag_name, self)
                 button.checkStateChanged.connect(self._filter_tags)
-                if tag_name in self._selected_tags[category]:
+                if tag_name in self._selected_tags.data.get(category, []):
                     button.setCheckState(Qt.CheckState.Checked)
-                elif tag_name in self._excluded_tags[category]:
+                elif tag_name in self._excluded_tags.data.get(category, []):
                     button.setCheckState(Qt.CheckState.PartiallyChecked)
                 else:
                     button.setCheckState(Qt.CheckState.Unchecked)
@@ -118,7 +113,7 @@ class FilterWidget(QWidget):
 
         form = QFormLayout()
         category = QComboBox()
-        category.addItems([cat.capitalize() for cat in Tags.TAGS().data.keys()])
+        category.addItems([cat.capitalize() for cat in Tags.manager.tags.data.keys()])
         category.setEditable(True)
         category.setInsertPolicy(QComboBox.InsertPolicy.InsertAlphabetically)
         tag = QLineEdit()
@@ -137,7 +132,7 @@ class FilterWidget(QWidget):
         layout.addWidget(btn_box)
 
         if dialog.exec():
-            Tags.create_new_tag(category.currentText().lower(), tag.text())
+            create_new_tag(category.currentText().lower(), tag.text())
             self.update_filter_tags()
 
     def filter_pdb_files(self) -> None:
@@ -166,7 +161,7 @@ class FilterWidget(QWidget):
     def _filter_pdb_type(self) -> None:
         button = cast(PDBTypeCheckBox, self.sender())
         if button.isChecked():
-            self._selected_types.append(button.pdb_type)
+            self._selected_types.add(button.pdb_type)
         else:
             self._selected_types.remove(button.pdb_type)
         self.filter_pdb_files()
@@ -194,32 +189,34 @@ class FilterWidget(QWidget):
     def load_settings(self) -> None:
         settings = QSettings()
         try:
-            self._excluded_tags = Tags.from_ids(
+            self._excluded_tags = Tags.manager.from_ids(
                 cast(
-                    list[int],
+                    set[int],
                     settings.value(f"FilterWidget/excluded_tags_{config.db.NAME}")
-                    or [],
+                    or set(),
                 )
             )
-            self._selected_tags = Tags.from_ids(
+            self._selected_tags = Tags.manager.from_ids(
                 cast(
-                    list[int],
+                    set[int],
                     settings.value(f"FilterWidget/selected_tags_{config.db.NAME}")
-                    or [],
+                    or set(),
                 )
             )
-            self._selected_types = cast(
-                list[str],
-                settings.value(f"FilterWidget/selected_types_{config.db.NAME}") or [],
+            self._selected_types = set(
+                cast(
+                    set[str],
+                    settings.value(f"FilterWidget/selected_types_{config.db.NAME}")
+                    or set(),
+                )
             )
-
         except Exception:
             logger.error(
                 f"Reading stettings failed for {config.db.NAME}, using defaults"
             )
             self._excluded_tags = Tags({})
             self._selected_tags = Tags({})
-            self._selected_types = config.db.VALID_PDB_TYPES
+            self._selected_types = set(config.db.PDB_TYPES.keys())
 
     def __del__(self):
         self.save_settings()
