@@ -17,7 +17,7 @@ from PySide6.QtWidgets import (
     QWidget,
 )
 
-from phystool.physgit import PhysGit
+from phystool.physgit import GitFile, PhysGit
 from phystool.qt.helper import QBusyDialog
 
 
@@ -40,9 +40,9 @@ class GitListFilesWidget(QTableWidget):
         header.setSectionResizeMode(0, QHeaderView.ResizeMode.Interactive)
         header.setSectionResizeMode(1, QHeaderView.ResizeMode.Stretch)
 
-        self._uuid_row_map: dict[int, str] = {}
-        for row, (uuid, git_file) in enumerate(self._physgit):
-            self._uuid_row_map[row] = uuid
+        self._row_git_file_map: dict[int, GitFile] = {}
+        for row, git_file in enumerate(self._physgit):
+            self._row_git_file_map[row] = git_file
             check_box = QCheckBox(git_file.status.name, self)
             self.setCellWidget(row, 0, check_box)
             self.setItem(row, 1, QTableWidgetItem(git_file.title))
@@ -52,7 +52,7 @@ class GitListFilesWidget(QTableWidget):
         row = self.currentRow()
         if row < 0:
             return
-        self.sig_diff.emit(self._physgit[self._uuid_row_map[row]].get_diff())
+        self.sig_diff.emit(self._row_git_file_map[row].get_diff())
 
     @Slot()
     def select_all(self) -> None:
@@ -67,7 +67,7 @@ class GitListFilesWidget(QTableWidget):
     def commit(self) -> str:
         for row in range(self.rowCount()):
             if self.cellWidget(row, 0).isChecked():
-                self._physgit.stage(self._uuid_row_map[row])
+                self._physgit.stage(self._row_git_file_map[row])
         return self._physgit.commit(for_terminal=False)
 
 
